@@ -6,18 +6,18 @@ from typing import Union
 
 import numpy as np
 import pandas as pd
+from timeseriesflattener.feature_spec_objects import (
+    AnySpec,
+    PredictorSpec,
+    StaticSpec,
+    TemporalSpec,
+)
 from wasabi import Printer
 
 from psycop_feature_generation.data_checks.utils import save_df_to_pretty_html_table
 from psycop_feature_generation.loaders.flattened.local_feature_loaders import (
     load_split_predictors,
 )
-from psycop_feature_generation.timeseriesflattener.feature_spec_objects import (
-    AnySpec,
-    PredictorSpec,
-    StaticSpec,
-    TemporalSpec,
-)
 
 UNICODE_HIST = {
     0: " ",
